/*=========================================================================

  Program:   Visualization Toolkit
  Module:    ObjectFactory.cxx

  Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/

#include <vtkmFilterOverrides.h>

#include <vtkObjectFactory.h>

#include <vector>

namespace
{

bool vtkmFilterOverridesEnabled = VTK_ENABLE_VTKM_OVERRIDES != 0;

struct FilterOverrides
{
  const char* Base;
  const char* Override;
};

#if VTK_ENABLE_VTKM_OVERRIDES
const std::vector<FilterOverrides> overrides = {
  };
#endif

} // namespace

void vtkmFilterOverrides::SetEnabled(bool value)
{
  static_cast<void>(value);

#if VTK_ENABLE_VTKM_OVERRIDES
  if (vtkmFilterOverridesEnabled == value)
  {
    return;
  }

  for (const auto& ovr : overrides)
  {
    vtkObjectFactory::SetAllEnableFlags(value, ovr.Base, ovr.Override);
  }

  vtkmFilterOverridesEnabled = value;
#endif
}

bool vtkmFilterOverrides::GetEnabled()
{
  return vtkmFilterOverridesEnabled;
}
